/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/*
 * This code has been autogenerated, do not edit
 */

#include <stdio.h>

#include "UsbProConfParser.h"
#include "UsbProConfMsg.h"

#include "UsbProConfMsgPrmReq.h"
#include "UsbProConfMsgPrmRep.h"
#include "UsbProConfMsgSprmReq.h"
#include "UsbProConfMsgSprmRep.h"
#include "UsbProConfMsgSerReq.h"
#include "UsbProConfMsgSerRep.h"

UsbProConfParser::UsbProConfParser() {}
UsbProConfParser::~UsbProConfParser() {}


/*
 * Pass the buffer and return a Message object
 * @param data  the data representing the serialized object
 * @param len	the length of the data
 */
UsbProConfMsg *UsbProConfParser::parse(const uint8_t *data, int len) {
  lla_usbpro_conf_msg *req = (lla_usbpro_conf_msg *) data;

  if(len < lla_usbpro_conf_header_size)
    return NULL;

   
  if ( req->plugid != 5)
    return NULL;
  
  switch(req->op) {
    case LLA_USBPRO_CONF_MSG_PRM_REQ:
      return parse_prm_req(req, len);
    case LLA_USBPRO_CONF_MSG_PRM_REP:
      return parse_prm_rep(req, len);
    case LLA_USBPRO_CONF_MSG_SPRM_REQ:
      return parse_sprm_req(req, len);
    case LLA_USBPRO_CONF_MSG_SPRM_REP:
      return parse_sprm_rep(req, len);
    case LLA_USBPRO_CONF_MSG_SER_REQ:
      return parse_ser_req(req, len);
    case LLA_USBPRO_CONF_MSG_SER_REP:
      return parse_ser_rep(req, len);
    default:
      return NULL;
  }
}


/*
 * Parses a param request message
 *
 * @param req	the request buffer
 * @param len 	the buffer length
 */
UsbProConfMsg *UsbProConfParser::parse_prm_req(lla_usbpro_conf_msg *req, int len) {
	
  if( len != sizeof(lla_usbpro_conf_msg_prm_req) + lla_usbpro_conf_header_size)
    return NULL;

  UsbProConfMsgPrmReq *m = new UsbProConfMsgPrmReq();

  return m;
}


/*
 * Parses a param reply message
 *
 * @param req	the request buffer
 * @param len 	the buffer length
 */
UsbProConfMsg *UsbProConfParser::parse_prm_rep(lla_usbpro_conf_msg *req, int len) {
	
  if( len != sizeof(lla_usbpro_conf_msg_prm_rep) + lla_usbpro_conf_header_size)
    return NULL;

  UsbProConfMsgPrmRep *m = new UsbProConfMsgPrmRep();

  m->set_firmware(req->data.prm_rep.firmware);
  m->set_brk(req->data.prm_rep.brk);
  m->set_mab(req->data.prm_rep.mab);
  m->set_rate(req->data.prm_rep.rate);
  return m;
}


/*
 * Parses a set param request message
 *
 * @param req	the request buffer
 * @param len 	the buffer length
 */
UsbProConfMsg *UsbProConfParser::parse_sprm_req(lla_usbpro_conf_msg *req, int len) {
	
  if( len != sizeof(lla_usbpro_conf_msg_sprm_req) + lla_usbpro_conf_header_size)
    return NULL;

  UsbProConfMsgSprmReq *m = new UsbProConfMsgSprmReq();

  m->set_brk(req->data.sprm_req.brk);
  m->set_mab(req->data.sprm_req.mab);
  m->set_rate(req->data.sprm_req.rate);
  return m;
}


/*
 * Parses a set param reply message
 *
 * @param req	the request buffer
 * @param len 	the buffer length
 */
UsbProConfMsg *UsbProConfParser::parse_sprm_rep(lla_usbpro_conf_msg *req, int len) {
	
  if( len != sizeof(lla_usbpro_conf_msg_sprm_rep) + lla_usbpro_conf_header_size)
    return NULL;

  UsbProConfMsgSprmRep *m = new UsbProConfMsgSprmRep();

  m->set_status(req->data.sprm_rep.status);
  return m;
}


/*
 * Parses a serial number request message
 *
 * @param req	the request buffer
 * @param len 	the buffer length
 */
UsbProConfMsg *UsbProConfParser::parse_ser_req(lla_usbpro_conf_msg *req, int len) {
	
  if( len != sizeof(lla_usbpro_conf_msg_ser_req) + lla_usbpro_conf_header_size)
    return NULL;

  UsbProConfMsgSerReq *m = new UsbProConfMsgSerReq();

  return m;
}


/*
 * Parses a serial number reply message
 *
 * @param req	the request buffer
 * @param len 	the buffer length
 */
UsbProConfMsg *UsbProConfParser::parse_ser_rep(lla_usbpro_conf_msg *req, int len) {
	
  if( len != sizeof(lla_usbpro_conf_msg_ser_rep) + lla_usbpro_conf_header_size)
    return NULL;

  UsbProConfMsgSerRep *m = new UsbProConfMsgSerRep();

  m->set_status(req->data.ser_rep.status);
  m->set_serial(req->data.ser_rep.serial, 4);
  return m;
}

